@@ -24,7 +24,7 @@ class DigitalCan(AbstractDwfDeviceSubApi):
         """Reset the CAN bus protocol functionality.
 
         Raises:
-            DwfLibraryError: There was an error while executing the *reset* operation.
+            DwfLibraryError: An error occurred while executing the *reset* operation.
         """
         result = self.lib.FDwfDigitalCanReset(self.hdwf)
         if result != RESULT_SUCCESS:
@@ -37,7 +37,7 @@ class DigitalCan(AbstractDwfDeviceSubApi):
             data_rate (float): The data-rate used by the receiver and transmitter.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalCanRateSet(self.hdwf, data_rate)
         if result != RESULT_SUCCESS:
@@ -50,7 +50,7 @@ class DigitalCan(AbstractDwfDeviceSubApi):
             polarity (bool): If True, set polarity to *high*.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalCanPolaritySet(self.hdwf, int(polarity))
         if result != RESULT_SUCCESS:
@@ -63,7 +63,7 @@ class DigitalCan(AbstractDwfDeviceSubApi):
             channel_index (int): The channel (digital pin number) on which to transmit data.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalCanTxSet(self.hdwf, channel_index)
         if result != RESULT_SUCCESS:
@@ -76,7 +76,7 @@ class DigitalCan(AbstractDwfDeviceSubApi):
             channel_index (int): The channel (digital pin number) on which to receive data.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalCanRxSet(self.hdwf, channel_index)
         if result != RESULT_SUCCESS:
@@ -93,7 +93,7 @@ class DigitalCan(AbstractDwfDeviceSubApi):
 
         Raises:
             PyDwfError: A request to transmit more than 8 bytes was made.
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         if len(data) > 8:
             raise PyDwfError("CAN message too long.")
@@ -123,7 +123,7 @@ class DigitalCan(AbstractDwfDeviceSubApi):
             Tuple[int, bool, bool, bytes, int]: A tuple (vID, extended, remote, data, status)
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
 
         c_vID      = typespec_ctypes.c_int()
