@@ -22,7 +22,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
         """Reset the I²C protocol instrument.
 
         Raises:
-            DwfLibraryError: There was an error while executing the *reset* operation.
+            DwfLibraryError: An error occurred while executing the *reset* operation.
         """
         result = self.lib.FDwfDigitalI2cReset(self.hdwf)
         if result != RESULT_SUCCESS:
@@ -35,7 +35,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
             int: "bus free" indicator.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_bus_free = typespec_ctypes.c_int()
         result = self.lib.FDwfDigitalI2cClear(self.hdwf, c_bus_free)
@@ -51,7 +51,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
             stretch_enable (bool): True to enable stretch, False to disable.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalI2cStretchSet(self.hdwf, bool(stretch_enable))
         if result != RESULT_SUCCESS:
@@ -61,11 +61,11 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
         """Set  I²C data rate, in Hz.
 
         Parameters:
-            data_rate (float):  I²C data rate. Often-encountered rates are 100 kHz and 400 kHz, but many
+            data_rate (float): I²C data rate. Often-encountered rates are 100 kHz and 400 kHz, but many
                 modern I²C devices support higher data rates. Check the datasheet.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalI2cRateSet(self.hdwf, data_rate)
         if result != RESULT_SUCCESS:
@@ -78,7 +78,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
             nak_last_read_byte (int): (undocumented)
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalI2cReadNakSet(self.hdwf, nak_last_read_byte)
         if result != RESULT_SUCCESS:
@@ -91,7 +91,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
             channel_index (int): The channel (digital pin number) on which to generate the SCL clock.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalI2cSclSet(self.hdwf, channel_index)
         if result != RESULT_SUCCESS:
@@ -104,7 +104,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
             channel_index (int): The channel (digital pin number) on which to send/receive SDA data.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         result = self.lib.FDwfDigitalI2cSdaSet(self.hdwf, channel_index)
         if result != RESULT_SUCCESS:
@@ -123,7 +123,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
                 The first element is the NAK indication; the second element is a list of values received.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_nak = typespec_ctypes.c_int()
 
@@ -166,7 +166,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
                 The first element is the NAK indication; the second element is a list of values received.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
 
         c_nak = typespec_ctypes.c_int()
@@ -196,7 +196,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
             int: NAK indication.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
 
         c_nak = typespec_ctypes.c_int()
@@ -228,7 +228,7 @@ class DigitalI2c(AbstractDwfDeviceSubApi):
             int: NAK indication.
 
         Raises:
-            DwfLibraryError: There was an error while executing the operation.
+            DwfLibraryError: An error occurred while executing the operation.
         """
         c_nak = typespec_ctypes.c_int()
 
